@@ -5,23 +5,18 @@
 
     Integrates the marshmallow serialization/deserialization library
     with your Flask application.
-
-    :copyright: (c) 2014-2016 by Steven Loria
-    :license: MIT, see LICENSE for more details.
 """
 import warnings
+from distutils.version import LooseVersion
+
+from marshmallow import fields as base_fields, exceptions, pprint
 
-from marshmallow import (
-    fields as base_fields,
-    exceptions,
-    pprint
-)
 from . import fields
 from .schema import Schema
 
 has_sqla = False
 try:
-    import flask_sqlalchemy  # flake8: noqa
+    import flask_sqlalchemy  # noqa: F401
 except ImportError:
     has_sqla = False
 else:
@@ -29,26 +24,18 @@ else:
         from . import sqla
     except ImportError:
         warnings.warn(
-            'Flask-SQLAlchemy integration requires '
-            'marshmallow-sqlalchemy to be installed.'
+            "Flask-SQLAlchemy integration requires "
+            "marshmallow-sqlalchemy to be installed."
         )
     else:
         has_sqla = True
 
-__version__ = '0.9.0'
-__author__ = 'Steven Loria'
-__license__ = 'MIT'
+__version__ = "0.10.0"
+__version_info__ = tuple(LooseVersion(__version__).version)
+__all__ = ["EXTENSION_NAME", "Marshmallow", "Schema", "fields", "exceptions", "pprint"]
 
-__all__ = [
-    'EXTENSION_NAME',
-    'Marshmallow',
-    'Schema',
-    'fields',
-    'exceptions',
-    'pprint'
-]
+EXTENSION_NAME = "flask-marshmallow"
 
-EXTENSION_NAME = 'flask-marshmallow'
 
 def _attach_fields(obj):
     """Attach all the marshmallow fields classes to ``obj``, including
@@ -89,14 +76,14 @@ class Marshmallow(object):
             })
 
 
-    In order to integrate with Flask-SQLAlchemy, this extension must by initialized *after*
+    In order to integrate with Flask-SQLAlchemy, this extension must be initialized *after*
     `flask_sqlalchemy.SQLAlchemy`. ::
 
             db = SQLAlchemy(app)
             ma = Marshmallow(app)
 
-    This gives you access to `ma.ModelSchema`, which generates a marshmallow
-    `~marshmallow.Schema` based on the passed in model. ::
+    This gives you access to `ma.ModelSchema` and `ma.TableSchema`, which generate
+    marshmallow `~marshmallow.Schema` classes based on the passed in model or table. ::
 
         class AuthorSchema(ma.ModelSchema):
             class Meta:
@@ -109,6 +96,7 @@ class Marshmallow(object):
         self.Schema = Schema
         if has_sqla:
             self.ModelSchema = sqla.ModelSchema
+            self.TableSchema = sqla.TableSchema
             self.HyperlinkRelated = sqla.HyperlinkRelated
         _attach_fields(self)
         if app is not None:
@@ -119,10 +107,10 @@ class Marshmallow(object):
 
         :param Flask app: The Flask application object.
         """
-        app.extensions = getattr(app, 'extensions', {})
+        app.extensions = getattr(app, "extensions", {})
 
         # If using Flask-SQLAlchemy, attach db.session to ModelSchema
-        if has_sqla and 'sqlalchemy' in app.extensions:
-            db = app.extensions['sqlalchemy'].db
+        if has_sqla and "sqlalchemy" in app.extensions:
+            db = app.extensions["sqlalchemy"].db
             self.ModelSchema.OPTIONS_CLASS.session = db.session
         app.extensions[EXTENSION_NAME] = self
